package Task::BeLike::SHARYANTO::Authored;
# ABSTRACT: Install all modules authored by SHARYANTO on CPAN

# note: list of pkgs generated by generate-pkg-lists-for-tbsha

our $VERSION = '0.16'; # VERSION


1;

__END__

=pod

=head1 NAME

Task::BeLike::SHARYANTO::Authored - Install all modules authored by SHARYANTO on CPAN

=head1 VERSION

version 0.16

=head1 DESCRIPTION

This task will install all modules authored by SHARYANTO currently on CPAN.
Excluded are other Task::* modules, or modules already deletd from CPAN.

=head1 TASK CONTENTS

=head2 Included modules

=head3 L<Acme::CPANAuthors::Indonesian>

=head3 L<Alt::Base>

=head3 L<Alt::Log::Any::App::FWR>

=head3 L<App::HTMLCalendarMonth::Indonesia>

=head3 L<App::HasPrereqs>

=head3 L<App::LintPrereqs>

=head3 L<App::ListPrereqs>

=head3 L<App::ListRevDeps>

=head3 L<App::OrgUtils>

=head3 L<App::ParseCPANChanges>

=head3 L<App::SerializeUtils>

=head3 L<App::UniqFiles>

=head3 L<App::cal::id>

=head3 L<App::dux>

=head3 L<App::osnames>

=head3 L<App::perlmv>

=head3 L<App::smtpstatus>

=head3 L<Array::Find>

=head3 L<Array::Iterator>

=head3 L<Bench>

=head3 L<Borang>

=head3 L<Builtin::Logged>

=head3 L<Business::BankCard>

=head3 L<Business::BankCard::Indonesia>

=head3 L<Business::BankList>

=head3 L<Business::BankList::Indonesia>

=head3 L<Business::ID::BCA>

=head3 L<Business::ID::Mandiri>

=head3 L<Business::ID::NIK>

=head3 L<Business::ID::NOPPBB>

=head3 L<Business::ID::NPWP>

=head3 L<Business::ID::SIM>

=head3 L<CPAN::Critic::Module::Abstract>

=head3 L<Calendar::Indonesia::Holiday>

=head3 L<Carp::Always::Dump>

=head3 L<Carp::Always::SyntaxHighlightSource>

=head3 L<Color::ANSI::Util>

=head3 L<Crypt::Password::Util>

=head3 L<Data::Clean::JSON>

=head3 L<Data::Dump::Ala::SHARYANTO>

=head3 L<Data::Dump::Color>

=head3 L<Data::Dump::OneLine>

=head3 L<Data::Dump::PHP>

=head3 L<Data::Dump::Partial>

=head3 L<Data::Dump::Ruby>

=head3 L<Data::Format::Pretty>

=head3 L<Data::Format::Pretty::Console>

=head3 L<Data::Format::Pretty::HTML>

=head3 L<Data::Format::Pretty::JSON>

=head3 L<Data::Format::Pretty::PHP>

=head3 L<Data::Format::Pretty::PHPSerialization>

=head3 L<Data::Format::Pretty::Perl>

=head3 L<Data::Format::Pretty::Ruby>

=head3 L<Data::Format::Pretty::YAML>

=head3 L<Data::ModeMerge>

=head3 L<Data::Sah>

=head3 L<Data::Unixish>

=head3 L<Data::Unixish::ansi>

=head3 L<DateTime::Format::Indonesian>

=head3 L<DefHash>

=head3 L<Devel::EndStats>

=head3 L<Dist::Create::TaskBeLikeFavorited>

=head3 L<Dist::Zilla::Plugin::Extras>

=head3 L<Dist::Zilla::Plugin::Rinci::Validate>

=head3 L<Dist::Zilla::Plugin::Test::Rinci>

=head3 L<Dist::Zilla::PluginBundle::SHARYANTO>

=head3 L<File::Append::Undoable>

=head3 L<File::Copy::Undoable>

=head3 L<File::Move::Undoable>

=head3 L<File::Patch::Undoable>

=head3 L<File::Prepend::Undoable>

=head3 L<File::RsyBak>

=head3 L<File::Slurp::Shortcuts>

=head3 L<File::Trash::FreeDesktop>

=head3 L<File::Trash::Undoable>

=head3 L<File::Truncate::Undoable>

=head3 L<File::Write::Rotate>

=head3 L<Finance::Bank::ID::BCA>

=head3 L<Finance::Bank::ID::BPRKS>

=head3 L<Finance::Bank::ID::Mandiri>

=head3 L<Finance::Currency::Convert::KlikBCA>

=head3 L<Gen::Test::Rinci::FuncResult>

=head3 L<Gepok>

=head3 L<Git::Bunch>

=head3 L<HTTP::Daemon::Patch::IPv6>

=head3 L<HTTP::Daemon::UNIX>

=head3 L<HTTP::Headers::Patch::DontUseStorable>

=head3 L<HTTP::Tiny::Patch::LogAny>

=head3 L<Hash::DefHash>

=head3 L<IOD>

=head3 L<JSON::Color>

=head3 L<LWP::Protocol::http::SocketUnixAlt>

=head3 L<LWP::UserAgent::Patch::HTTPSHardTimeout>

=head3 L<LWP::UserAgent::Patch::LogRequestContent>

=head3 L<LWP::UserAgent::Patch::LogResponse>

=head3 L<Language::Expr>

=head3 L<Ledger::Parser>

=head3 L<Lingua::EN::Number::Format::MixWithWords>

=head3 L<Lingua::ID::Number::Format::MixWithWords>

=head3 L<Lingua::ID::Nums2Words>

=head3 L<Lingua::ID::Words2Nums>

=head3 L<Lingua::SU::Nums2Words>

=head3 L<Lingua::ZH::PinyinConvert::ID>

=head3 L<Locale::ID::GuessGender::FromFirstName>

=head3 L<Locale::ID::Locality>

=head3 L<Locale::ID::Province>

=head3 L<Log::Any::Adapter::Callback>

=head3 L<Log::Any::Adapter::Core::Patch::SetDumperIndent>

=head3 L<Log::Any::Adapter::Core::Patch::UseDataDump>

=head3 L<Log::Any::Adapter::Core::Patch::UseDataDumperPerltidy>

=head3 L<Log::Any::Adapter::ScreenColoredLevel>

=head3 L<Log::Any::For::Class>

=head3 L<Log::Any::For::DBI>

=head3 L<Log::Any::For::HTTP::Tiny>

=head3 L<Log::Any::For::LWP>

=head3 L<Log::Any::For::STDERR>

=head3 L<Log::Dispatch::Dir>

=head3 L<Log::Dispatch::FileWriteRotate>

=head3 L<Media::Info>

=head3 L<Media::Info::Mplayer>

=head3 L<Module::Patch>

=head3 L<Monkey::Patch::Action>

=head3 L<Net::HTTP::Methods::Patch::LogRequest>

=head3 L<Number::Closest::NonOO>

=head3 L<Object::BlankStr>

=head3 L<Object::NulStr>

=head3 L<Object::SpaceBackStr>

=head3 L<Org::Parser>

=head3 L<Org::To::HTML>

=head3 L<Org::To::Pod>

=head3 L<Org::To::Text>

=head3 L<Parse::Netstat>

=head3 L<Parse::Number::EN>

=head3 L<Parse::Number::ID>

=head3 L<Parse::PhoneNumber::ID>

=head3 L<Parse::VarName>

=head3 L<Perinci>

=head3 L<Perinci::Access>

=head3 L<Perinci::Access::Base>

=head3 L<Perinci::Access::HTTP::Client>

=head3 L<Perinci::Access::HTTP::Server>

=head3 L<Perinci::Access::Perl>

=head3 L<Perinci::Access::Simple::Client>

=head3 L<Perinci::Access::Simple::Server>

=head3 L<Perinci::BashComplete>

=head3 L<Perinci::CmdLine>

=head3 L<Perinci::Easy>

=head3 L<Perinci::Examples>

=head3 L<Perinci::Examples::Bin>

=head3 L<Perinci::Exporter>

=head3 L<Perinci::Gen::ForModule>

=head3 L<Perinci::Object>

=head3 L<Perinci::Result::Format>

=head3 L<Perinci::Sub::ConvertArgs::Argv>

=head3 L<Perinci::Sub::ConvertArgs::Array>

=head3 L<Perinci::Sub::Dep::pm>

=head3 L<Perinci::Sub::DepChecker>

=head3 L<Perinci::Sub::DepUtil>

=head3 L<Perinci::Sub::FeatureUtil>

=head3 L<Perinci::Sub::Gen>

=head3 L<Perinci::Sub::Gen::AccessTable>

=head3 L<Perinci::Sub::Gen::AccessTable::DBI>

=head3 L<Perinci::Sub::GetArgs::Argv>

=head3 L<Perinci::Sub::GetArgs::Array>

=head3 L<Perinci::Sub::Property::curry>

=head3 L<Perinci::Sub::Property::dies_on_error>

=head3 L<Perinci::Sub::Property::drops_privilege>

=head3 L<Perinci::Sub::Property::result_postfilter>

=head3 L<Perinci::Sub::Property::retry>

=head3 L<Perinci::Sub::Property::timeout>

=head3 L<Perinci::Sub::PropertyUtil>

=head3 L<Perinci::Sub::To::POD>

=head3 L<Perinci::Sub::To::Text>

=head3 L<Perinci::Sub::Wrapper>

=head3 L<Perinci::Sub::Wrapper::Patch::HandlePHPArray>

=head3 L<Perinci::To::HTML>

=head3 L<Perinci::To::POD>

=head3 L<Perinci::To::Text>

=head3 L<Perinci::Tx::Manager>

=head3 L<Perinci::Use>

=head3 L<Perinci::Util>

=head3 L<Perinci::Web>

=head3 L<Perl::Stripper>

=head3 L<Pod::Weaver::Plugin::Eval>

=head3 L<Pod::Weaver::Plugin::Perinci>

=head3 L<Pod::Weaver::PluginBundle::SHARYANTO>

=head3 L<Pod::Weaver::Section::Changes>

=head3 L<Process::Govern>

=head3 L<Process::KillTree>

=head3 L<Progress::Any>

=head3 L<Progress::Any::Output>

=head3 L<Progress::Any::Output::Callback>

=head3 L<Progress::Any::Output::LogAny>

=head3 L<Progress::Any::Output::TermMessage>

=head3 L<Progress::Any::Output::TermProgressBarColor>

=head3 L<RSS::From::Forum::vBulletin>

=head3 L<RSS::From::Twitter>

=head3 L<Riap>

=head3 L<Rinci>

=head3 L<Rinci::Schema>

=head3 L<SHARYANTO>

=head3 L<SHARYANTO::Color::Util>

=head3 L<SHARYANTO::Data::Util>

=head3 L<SHARYANTO::File::Util>

=head3 L<SHARYANTO::Number::Util>

=head3 L<SHARYANTO::Package::Util>

=head3 L<SHARYANTO::Proc::Util>

=head3 L<SHARYANTO::SQL::Schema>

=head3 L<SHARYANTO::String::Util>

=head3 L<SHARYANTO::Utils>

=head3 L<SHARYANTO::YAML::Any>

=head3 L<Sah>

=head3 L<Serabi>

=head3 L<Setup>

=head3 L<Setup::File>

=head3 L<Setup::File::Symlink>

=head3 L<Setup::File::TextFragment>

=head3 L<Setup::Unix::User>

=head3 L<Software::Catalog>

=head3 L<Software::Release::Watch>

=head3 L<Software::Release::Watch::SW::wordpress>

=head3 L<Syntax::Feature::EachOnArray>

=head3 L<SyntaxHighlight::Any>

=head3 L<Term::Detect::Software>

=head3 L<Term::ProgressBar::Color>

=head3 L<Test::Rinci>

=head3 L<Test::Sah>

=head3 L<Text::ANSI::Util>

=head3 L<Text::ANSITable>

=head3 L<Text::ANSITable::BorderStyle::Extra>

=head3 L<Text::ANSITable::ColorTheme::Extra>

=head3 L<Text::Fragment>

=head3 L<Text::WideChar::Util>

=head3 L<Text::sprintfn>

=head3 L<Tie::Diamond>

=head3 L<Tie::Handle::FileWriteRotate>

=head3 L<Time::Duration::Patch::Millisecond>

=head3 L<Time::Duration::id>

=head3 L<UUID::Random::Patch::UseMRS>

=head3 L<Unix::Passwd::File>

=head3 L<Unixish>

=head3 L<WWW::GudangAPI>

=head3 L<Web::Detect>

=head3 L<YAML::Tiny::Color>

=head3 L<tainting>

=head3 L<version::Restrict>

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
